# Django Airavata

Python 2.7 [![Build Status 2.7](http://jenkins.lasolution.be/buildStatus/icon?job=Polla/PYTHON=System-CPython-2.7)](http://jenkins.lasolution.be/view/Levit/job/Polla/PYTHON=System-CPython-2.7)
Python 3.2 [![Build Status 3.2](http://jenkins.lasolution.be/buildStatus/icon?job=Polla/PYTHON=System-CPython-3.2)](http://jenkins.lasolution.be/view/Levit/job/Polla/PYTHON=System-CPython-3.2/)
Python 3.4 [![Build Status 3.4](http://jenkins.lasolution.be/buildStatus/icon?job=Polla/PYTHON=CPython-3.4)](http://jenkins.lasolution.be/view/Levit/job/Polla/PYTHON=CPython-3.4/)


Docs [![Docs status](https://readthedocs.org/projects/django-polla/badge/?version=latest)](https://readthedocs.org/projects/django-polla/badge/?version=latest)
PyPi [![PyPi version](https://pypip.in/v/polla/badge.png)](https://crate.io/packages/polla/)
[![PyPi downloads](https://pypip.in/d/polla/badge.png)](https://crate.io/packages/polla/)


Airavata is a mythological white elephant who carries the Hindu god Indra. Airavata has four tusks and seven trunks and is spotless white. [source on Wikipedia](https://en.wikipedia.org/wiki/Airavata).

Airavata is also a Django 1.8+ library that allows you to hosts multiple dynamic sites running on a single Django instance/db.

I have been using a customized version of [dynamicsites](https://bitbucket.org/uysrc/django-dynamicsites/overview) for a while now. But with the new features from Django 1.7 and 1.8, there exists another simpler, and more pythonesque IMHO, way to achieve the same results. Polla is an attempt at that *other* way.


See documentation on [ReadTheDocs](http://django-polla.readthedocs.org/en/latest/)

Thanks to:

- @ashwoods for the new name :-)